django-grpahql-oauth2
======================

*django-graphql-oauth2* is a Django application that provides
customizable OAuth2\-authentication for your Django projects.

License
=======

*django-graphql-oauth2* is a fork of  `django-oauth2 <https://github.com/stormsherpa/django-oauth2-provider>`_ which is released under the MIT License. Please see the LICENSE file for details.
